@@ -456,6 +456,9 @@ if ($multiline) {
 		if ($d->{'dns_ip'}) {
 			print "    External IP address: $d->{'dns_ip'}\n";
 			}
+		if ($d->{'dns_ip6'}) {
+			print "    External IPv6 address: $d->{'dns_ip6'}\n";
+			}
 		print "    Features: ",
 			join(" ", grep { $d->{$_} } @features),"\n";
 		print "    Plugins: ",
@@ -757,6 +760,13 @@ if ($multiline) {
 			print "    SSL provider type: ",
 			      ($acme->{'type'} || $acme->{'url'}),"\n";
 			}
+		if (defined($d->{'letsencrypt_connectivity'})) {
+			print "    SSL provider connectivity check: ",
+			    ($d->{'letsencrypt_connectivity'} == 2 ?
+				"Check connectivity" :
+			     $d->{'letsencrypt_connectivity'} == 1 ?
+				"Validate domain" : "None"),"\n";
+			}
 
 		# Show SSL cert usage by other services
 		if ($multiline == 1) {
